==> blancoStringConverter-0.1.0-src.zip: blancoStringConverter/blanco.python/main/blanco/sample/stringconverter/SampleKatakanaHan2ZenStringConverter.py <==
# -*- coding: cp932 -*-
"""̃\[XR[h blanco FrameworkɂĎĂ܂B
"""
class SampleKatakanaHan2ZenStringConverter:
    """pJ^JiSpJ^Ji̕ϊ̃TvBblancoStringConverter̎ɂ͉e܂B
    """

    """u`B
    """
    STRING_CONVERT_DEF = [[ '', 'B' ]
, [ '', 'u' ]
, [ '', 'v' ]
, [ '', 'A' ]
, [ '', 'E' ]
, [ '', '' ]
, [ '', 'K' ]
, [ '', 'M' ]
, [ '', 'O' ]
, [ '', 'Q' ]
, [ '', 'S' ]
, [ '', 'U' ]
, [ '', 'W' ]
, [ '', 'Y' ]
, [ '', '[' ]
, [ '', ']' ]
, [ '', '_' ]
, [ '', 'a' ]
, [ '', 'd' ]
, [ '', 'f' ]
, [ '', 'h' ]
, [ '', 'o' ]
, [ '', 'r' ]
, [ '', 'u' ]
, [ '', 'x' ]
, [ '', '{' ]
, [ '', 'p' ]
, [ '', 's' ]
, [ '', 'v' ]
, [ '', 'y' ]
, [ '', '|' ]
, [ '', '@' ]
, [ '', 'B' ]
, [ '', 'D' ]
, [ '', 'F' ]
, [ '', 'H' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', 'b' ]
, [ '', '[' ]
, [ '', 'A' ]
, [ '', 'C' ]
, [ '', 'E' ]
, [ '', 'G' ]
, [ '', 'I' ]
, [ '', 'J' ]
, [ '', 'L' ]
, [ '', 'N' ]
, [ '', 'P' ]
, [ '', 'R' ]
, [ '', 'T' ]
, [ '', 'V' ]
, [ '', 'X' ]
, [ '', 'Z' ]
, [ '', '\' ]
, [ '', '^' ]
, [ '', '`' ]
, [ '', 'c' ]
, [ '', 'e' ]
, [ '', 'g' ]
, [ '', 'i' ]
, [ '', 'j' ]
, [ '', 'k' ]
, [ '', 'l' ]
, [ '', 'm' ]
, [ '', 'n' ]
, [ '', 'q' ]
, [ '', 't' ]
, [ '', 'w' ]
, [ '', 'z' ]
, [ '', '}' ]
, [ '', '~' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', 'J' ]
, [ '', 'K' ]
 ]

    def convert(self, argCheck):
        """ϊ`ɏ]Aϊ܂B

        self -- ̃\bh܂ރNXgB
        argCheck -- ϊΏۂ̕B
        return -- ϊ`ɂĕϊꂽBϊ`ɂЂƂvȂꍇɂ͌̕񂪖߂܂B
        """
        if argCheck is None:
            raise "\bh[convert]̃p[^[argCheck]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        wrkString = ''
        index = 0
        while index < len(argCheck):
            look = argCheck[index:]
            isFound = False
            for indexDef in range(len(self.STRING_CONVERT_DEF)):
                if look.find(self.STRING_CONVERT_DEF[indexDef][0]) == 0:
                    wrkString += self.STRING_CONVERT_DEF[indexDef][1]
                    index += len(self.STRING_CONVERT_DEF[indexDef][0])
                    isFound = True
                    break
                #end
            #end
            if isFound == False:
                wrkString += unicode(argCheck[index:])[0].encode()
                index = index + len(unicode(argCheck[index:])[0].encode())
            #end
        #end

        return wrkString
    #end
#end

==> blancoStringConverter-0.1.1-src.zip: blancoStringConverter/blanco.python/main/blanco/sample/stringconverter/SampleKatakanaHan2ZenStringConverter.py <==
# -*- coding: cp932 -*-
"""̃\[XR[h blanco FrameworkɂĎĂ܂B
"""
class SampleKatakanaHan2ZenStringConverter:
    """pJ^JiSpJ^Ji̕ϊ̃TvBblancoStringConverter̎ɂ͉e܂B
    """

    """u`B
    """
    STRING_CONVERT_DEF = [[ '', 'B' ]
, [ '', 'u' ]
, [ '', 'v' ]
, [ '', 'A' ]
, [ '', 'E' ]
, [ '', '' ]
, [ '', 'K' ]
, [ '', 'M' ]
, [ '', 'O' ]
, [ '', 'Q' ]
, [ '', 'S' ]
, [ '', 'U' ]
, [ '', 'W' ]
, [ '', 'Y' ]
, [ '', '[' ]
, [ '', ']' ]
, [ '', '_' ]
, [ '', 'a' ]
, [ '', 'd' ]
, [ '', 'f' ]
, [ '', 'h' ]
, [ '', 'o' ]
, [ '', 'r' ]
, [ '', 'u' ]
, [ '', 'x' ]
, [ '', '{' ]
, [ '', 'p' ]
, [ '', 's' ]
, [ '', 'v' ]
, [ '', 'y' ]
, [ '', '|' ]
, [ '', '@' ]
, [ '', 'B' ]
, [ '', 'D' ]
, [ '', 'F' ]
, [ '', 'H' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', 'b' ]
, [ '', '[' ]
, [ '', 'A' ]
, [ '', 'C' ]
, [ '', 'E' ]
, [ '', 'G' ]
, [ '', 'I' ]
, [ '', 'J' ]
, [ '', 'L' ]
, [ '', 'N' ]
, [ '', 'P' ]
, [ '', 'R' ]
, [ '', 'T' ]
, [ '', 'V' ]
, [ '', 'X' ]
, [ '', 'Z' ]
, [ '', '\' ]
, [ '', '^' ]
, [ '', '`' ]
, [ '', 'c' ]
, [ '', 'e' ]
, [ '', 'g' ]
, [ '', 'i' ]
, [ '', 'j' ]
, [ '', 'k' ]
, [ '', 'l' ]
, [ '', 'm' ]
, [ '', 'n' ]
, [ '', 'q' ]
, [ '', 't' ]
, [ '', 'w' ]
, [ '', 'z' ]
, [ '', '}' ]
, [ '', '~' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', '' ]
, [ '', 'J' ]
, [ '', 'K' ]
 ]

    def convert(self, argCheck):
        """ϊ`ɏ]Aϊ܂B

        self -- ̃\bh܂ރNXgB
        argCheck -- ϊΏۂ̕B
        return -- ϊ`ɂĕϊꂽBϊ`ɂЂƂvȂꍇɂ͌̕񂪖߂܂B
        """
        if argCheck is None:
            raise ValueError, "\bh[convert]̃p[^[argCheck]null^܂BÃp[^null^邱Ƃ͂ł܂B"
        #end

        wrkString = ''
        index = 0
        while index < len(argCheck):
            look = argCheck[index:]
            isFound = False
            for indexDef in range(len(self.STRING_CONVERT_DEF)):
                if look.find(self.STRING_CONVERT_DEF[indexDef][0]) == 0:
                    wrkString += self.STRING_CONVERT_DEF[indexDef][1]
                    index += len(self.STRING_CONVERT_DEF[indexDef][0])
                    isFound = True
                    break
                #end
            #end
            if isFound == False:
                wrkString += unicode(argCheck[index:])[0].encode()
                index = index + len(unicode(argCheck[index:])[0].encode())
            #end
        #end

        return wrkString
    #end
#end
